import requests


class Session(object):

    def __init__(self, token=None):
        self.next_call = None
        self.session = requests.Session()
        self.token = token

    def query(self, end_point_str, param_dict=None):

        if param_dict is not None:
            param_dict.update({"token": self.token})
            param_dict.update({"format": "json"})
       
        response = self.session.get("http://webhose.io/" + end_point_str, params=param_dict)
        if response.status_code != 200:
            raise Exception(response.text)

        _output = response.json()
        self.next_call = _output['next']
        return _output

    def get_next(self):
        return self.query(self.next_call[1:])


__session = Session()


def config(token):
    __session.token = token


def query(end_point_str, param_dict=None):
    return __session.query(end_point_str, param_dict)


def get_next():
    return __session.get_next()





from codecs import open

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

with open('README.md', 'r', 'utf-8') as f:
    readme = f.read()

setup(
    name='webhoseio',
    packages=['webhoseio'],
    version='0.4',
    author='Ran Geva',
    author_email='ran@webhose.io',
    url='https://github.com/Webhose/webhoseio-python',
    license='MIT',
    description='Simple client library for the webhose.io REST API',
    long_description=readme,
    install_requires=[
        "requests >= 2.0.0"
    ],
    classifiers=(
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6'
    )
)
